.. e3-core documentation master file, created by
   sphinx-quickstart on Fri May 19 23:56:17 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to e3-core's documentation!
###################################

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   intro
   quickstart
   decision_graph
   plugins
   requirements



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
